@@ -1,4 +1,4 @@
-/* $Id: rcfile.c 4281 2008-07-13 16:44:19Z astyanax $ */
+/* $Id: rcfile.c 4315 2008-08-30 05:16:20Z astyanax $ */
 /**************************************************************************
  *   rcfile.c                                                             *
  *                                                                        *
@@ -217,19 +217,19 @@ char *parse_next_regex(char *ptr)
 bool nregcomp(const char *regex, int eflags)
 {
     regex_t preg;
-    int rc = regcomp(&preg, regex, REG_EXTENDED | eflags);
+    const char *r = fixbounds(regex);
+    int rc = regcomp(&preg, r, REG_EXTENDED | eflags);
 
     if (rc != 0) {
 	size_t len = regerror(rc, &preg, NULL, 0);
 	char *str = charalloc(len);
 
 	regerror(rc, &preg, str, len);
-	rcfile_error(N_("Bad regex \"%s\": %s"), regex, str);
+	rcfile_error(N_("Bad regex \"%s\": %s"), r, str);
 	free(str);
     }
 
     regfree(&preg);
-
     return (rc == 0);
 }
 
@@ -1044,8 +1044,11 @@ void do_rcfile(void)
     if (homedir == NULL)
 	rcfile_error(N_("I can't find my home directory!  Wah!"));
     else {
-	nanorc = charealloc(nanorc, strlen(homedir) + 9);
-	sprintf(nanorc, "%s/.nanorc", homedir);
+#ifndef RCFILE_NAME
+#define RCFILE_NAME ".nanorc"
+#endif
+	nanorc = charealloc(nanorc, strlen(homedir) + strlen(RCFILE_NAME) + 2);
+	sprintf(nanorc, "%s/%s", homedir, RCFILE_NAME);
 
 	/* Don't open directories, character files, or block files. */
 	if (stat(nanorc, &rcinfo) != -1) {
